@@ -26,13 +26,14 @@ def format_id_with_dashes(id):
 
 def get_google_ads_account(
     base_account: BaseAccount,
-    clients_service_url: str,
-    firebase_api_key: str,
-    gcp_credentials_path: str,
+    clients_service_url: Optional[str] = None,
+    firebase_api_key: Optional[str] = None,
+    gcp_credentials_path: Optional[str] = None,
     auth_enabled: bool = True
 ) -> Dict:
-    account_id = format_id_with_dashes(base_account['id'])
-    url = f"{clients_service_url}/api/google-ads-account?account_id={account_id}&client_id={base_account['client_id']}"
+    if not clients_service_url or not firebase_api_key or not gcp_credentials_path:
+                raise BadRequestError('clients_service_url or firebase_api_key or  gcp_credentials_path should not be None if google_ads_account is not provided')
+    url = f"{clients_service_url}/api/google-ads-account?account_id={base_account['id']}&client_id={base_account['client_id']}"
     accounts = call_get_route(
         url,
         firebase_api_key,
@@ -71,12 +72,14 @@ def get_login_customer_id_and_developer_token(mcc_credentials_path: str):
 
     return str(parsed_credentials_file["login_customer_id"]), parsed_credentials_file["developer_token"]
 
+
 def _init_datastore_client(gcp_credentials_path, gcp_project):
     if not gcp_credentials_path and not gcp_project:
             raise BadRequestError('gcp_credentials_path or gcp_project should not be None if datastore_client is not provided')
     return DatastoreClient.from_service_account_json(
             gcp_credentials_path, project=gcp_project)
 
+
 def _get_user_initialized_client(
     user_email: str,
     secret_key_file: str,
@@ -87,10 +90,8 @@ def _get_user_initialized_client(
     login_customer_id: Optional[str] = None,
 ):
     user_credentials = _get_google_ads_user_crendential(user_email, datastore_client, gcp_credentials_path, gcp_project)
-    credentials = decrypt(user_credentials['credentials'], secret_key_file).decode('utf-8')
-    credentials = Credentials(
-        **json.loads(credentials)
-    )
+    credentials = init_google_ads_credentials(user_credentials['credentials'], secret_key_file)
+
     if login_customer_id is None:
         return GoogleAdsClient(
             credentials,
@@ -101,3 +102,9 @@ def _get_user_initialized_client(
         developer_token,
         login_customer_id=login_customer_id
     )
+
+
+def init_google_ads_credentials(credentials_encrypt: bytes, secret_key_file: str,):
+    credentials = json.loads(decrypt(credentials_encrypt, secret_key_file).decode('utf-8'))
+    credentials['token'] = None
+    return Credentials(**credentials)
